Welcome to satsense's documentation!
====================================

Satsense is a Python library for land use/cover classification using satellite imagery.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   notebooks/index
   api/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
